@@ -54,16 +54,31 @@ def plotting_positions(failures=None, right_censored=None, a=None):
     """
     Calculates the plotting positions for plotting on probability paper
     This function is primarily used by the probability plotting functions.
+    The order of the input data is preserved (not sorted).
 
     Inputs:
     failures - the array or list of failure times
     right_censored - the array or list of right censored failure times
-    a - the heuristic constant for plotting positions of the form (k-a)/(n+1-2a). Default is a=0.3 which is the median rank method (same as the default in Minitab).
+    a - the heuristic constant for plotting positions of the form (k-a)/(n+1-2a). Default is a=0.3 which is the median rank method (same as the default in Minitab and Reliasoft).
         Must be in the range 0 to 1. For more heuristics, see: https://en.wikipedia.org/wiki/Q%E2%80%93Q_plot#Heuristics
 
     Outputs:
     x,y - the x and y plotting positions as lists
     """
+
+    # error checking the input
+    if type(failures) in [list, np.ndarray]:
+        f = failures
+    else:
+        raise ValueError("failures must be specified as an array or list")
+
+    if type(right_censored) == type(None):
+        rc = np.array([])
+    elif type(right_censored) in [np.ndarray, list]:
+        rc = right_censored
+    else:
+        raise ValueError("if specified, right_censored must be an array or list")
+
     if a is None:
         a = 0.3
     elif a < 0 or a > 1:
@@ -71,23 +86,7 @@ def plotting_positions(failures=None, right_censored=None, a=None):
             "a must be in the range 0 to 1. Default is 0.3 which gives the median rank. For more information see https://en.wikipedia.org/wiki/Q%E2%80%93Q_plot#Heuristics"
         )
 
-    if failures is None:
-        raise ValueError("failures must be specified as an array or list")
-    elif type(failures) == np.ndarray:
-        f = np.sort(failures)
-    elif type(failures) == list:
-        f = np.sort(np.array(failures))
-    else:
-        raise ValueError("failures must be specified as an array or list")
-    if right_censored is None:
-        rc = np.array([])
-    elif type(right_censored) == np.ndarray:
-        rc = np.sort(right_censored)
-    elif type(right_censored) == list:
-        rc = np.sort(np.array(right_censored))
-    else:
-        raise ValueError("if specified, right_censored must be an array or list")
-
+    # construct the dataframe for the rank adjustment method
     f_codes = np.ones_like(f)
     rc_codes = np.zeros_like(rc)
     cens_codes = np.hstack([f_codes, rc_codes])
@@ -101,7 +100,6 @@ def plotting_positions(failures=None, right_censored=None, a=None):
     reverse_i = failure_rows["reverse_i"].values
     c = list(df_sorted["cens_codes"].values)
     leading_cens = c.index(1)
-    # this is the rank adjustment method
     if leading_cens > 0:  # there are censored items before the first failure
         k = np.arange(1, len(reverse_i) + 1)
         adjusted_rank2 = [0]
@@ -121,8 +119,15 @@ def plotting_positions(failures=None, right_censored=None, a=None):
     F = []
     for i in adjusted_rank:
         F.append((i - a) / (n + 1 - 2 * a))
-    x = list(f)
-    y = F
+
+    # restore the original order of the points using the index from the sorted dataframe
+    idx = failure_rows.index.values
+    df2 = pd.DataFrame(
+        data={"x": failure_rows.times.values, "y": F, "idx": idx},
+        columns=["x", "y", "idx"],
+    ).sort_values(by="idx")
+    x = df2.x.values
+    y = df2.y.values
     return x, y
 
 
@@ -135,6 +140,7 @@ def Weibull_probability_plot(
     CI=0.95,
     CI_type="time",
     show_fitted_distribution=True,
+    show_scatter_points=True,
     **kwargs
 ):
     """
@@ -145,7 +151,8 @@ def Weibull_probability_plot(
     failures - the array or list of failure times
     right_censored - the array or list of right censored failure times
     fit_gamma - True/False. Default is False. Specify this as True in order to fit the Weibull_3P distribution and scale the x-axis to time - gamma.
-    show_fitted_distribution - True/False. If true, the fitted distribution will be plotted on the probability plot. Defaults to True
+    show_fitted_distribution - True/False. If True, the fitted distribution will be plotted on the probability plot. Defaults to True
+    show_scatter_points - True/False. If True, the plot will include the scatter points from the failure times. Defaults to True.
     a - the heuristic constant for plotting positions of the form (k-a)/(n+1-2a). Default is a=0.3 which is the median rank method (same as the default in Minitab).
         For more heuristics, see: https://en.wikipedia.org/wiki/Q%E2%80%93Q_plot#Heuristics
     CI - the confidence interval for the bounds. Default is 0.95 for 95% CI.
@@ -277,7 +284,8 @@ def Weibull_probability_plot(
 
     # plot the failure points and format the scale and axes
     x, y = plotting_positions(failures=failures, right_censored=right_censored, a=a)
-    plt.scatter(x, y, marker=".", linewidth=2, c=data_color)
+    if show_scatter_points is True:
+        plt.scatter(x, y, marker=".", linewidth=2, c=data_color)
     plt.gca().set_yscale(
         "function",
         functions=(axes_transforms.weibull_forward, axes_transforms.weibull_inverse),
@@ -311,6 +319,7 @@ def Loglogistic_probability_plot(
     CI=0.95,
     CI_type="time",
     show_fitted_distribution=True,
+    show_scatter_points=True,
     **kwargs
 ):
     """
@@ -321,7 +330,8 @@ def Loglogistic_probability_plot(
     failures - the array or list of failure times
     right_censored - the array or list of right censored failure times
     fit_gamma - True/False. Default is False. Specify this as True in order to fit the Loglogistic_3P distribution and scale the x-axis to time - gamma.
-    show_fitted_distribution - True/False. If true, the fitted distribution will be plotted on the probability plot. Defaults to True
+    show_fitted_distribution - True/False. If True, the fitted distribution will be plotted on the probability plot. Defaults to True
+    show_scatter_points - True/False. If True, the plot will include the scatter points from the failure times. Defaults to True.
     a - the heuristic constant for plotting positions of the form (k-a)/(n+1-2a). Default is a=0.3 which is the median rank method (same as the default in Minitab).
         For more heuristics, see: https://en.wikipedia.org/wiki/Q%E2%80%93Q_plot#Heuristics
     CI - the confidence interval for the bounds. Default is 0.95 for 95% CI.
@@ -453,7 +463,8 @@ def Loglogistic_probability_plot(
 
     # plot the failure points and format the scale and axes
     x, y = plotting_positions(failures=failures, right_censored=right_censored, a=a)
-    plt.scatter(x, y, marker=".", linewidth=2, c=data_color)
+    if show_scatter_points is True:
+        plt.scatter(x, y, marker=".", linewidth=2, c=data_color)
     plt.gca().set_yscale(
         "function",
         functions=(
@@ -489,6 +500,7 @@ def Exponential_probability_plot_Weibull_Scale(
     a=None,
     CI=0.95,
     show_fitted_distribution=True,
+    show_scatter_points=True,
     **kwargs
 ):
     """
@@ -503,6 +515,7 @@ def Exponential_probability_plot_Weibull_Scale(
     right_censored - the array or list of right censored failure times
     fit_gamma - True/False. Default is False. Specify this as True in order to fit the Exponential_2P distribution and scale the x-axis to time - gamma.
     show_fitted_distribution - True/False. If True, the fitted distribution will be plotted on the probability plot. Defaults to True
+    show_scatter_points - True/False. If True, the plot will include the scatter points from the failure times. Defaults to True.
     a - the heuristic constant for plotting positions of the form (k-a)/(n+1-2a). Default is a=0.3 which is the median rank method (same as the default in Minitab).
         For more heuristics, see: https://en.wikipedia.org/wiki/Q%E2%80%93Q_plot#Heuristics
     CI - the confidence interval for the bounds. Default is 0.95 for 95% CI.
@@ -614,7 +627,8 @@ def Exponential_probability_plot_Weibull_Scale(
 
     # plot the failure points and format the scale and axes
     x, y = plotting_positions(failures=failures, right_censored=right_censored, a=a)
-    plt.scatter(x, y, marker=".", linewidth=2, c=data_color)
+    if show_scatter_points is True:
+        plt.scatter(x, y, marker=".", linewidth=2, c=data_color)
     plt.gca().set_yscale(
         "function",
         functions=(axes_transforms.weibull_forward, axes_transforms.weibull_inverse),
@@ -644,9 +658,10 @@ def Gumbel_probability_plot(
     right_censored=None,
     __fitted_dist_params=None,
     a=None,
-    show_fitted_distribution=True,
     CI=0.95,
     CI_type="time",
+    show_fitted_distribution=True,
+    show_scatter_points=True,
     **kwargs
 ):
     """
@@ -657,6 +672,7 @@ def Gumbel_probability_plot(
     failures - the array or list of failure times
     right_censored - the array or list of right censored failure times
     show_fitted_distribution - True/False. If True, the fitted distribution will be plotted on the probability plot. Defaults to True
+    show_scatter_points - True/False. If True, the plot will include the scatter points from the failure times. Defaults to True.
     a - the heuristic constant for plotting positions of the form (k-a)/(n+1-2a). Default is a=0.3 which is the median rank method (same as the default in Minitab).
         For more heuristics, see: https://en.wikipedia.org/wiki/Q%E2%80%93Q_plot#Heuristics
     CI - the confidence interval for the bounds. Default is 0.95 for 95% CI.
@@ -732,7 +748,8 @@ def Gumbel_probability_plot(
         )
 
     x, y = plotting_positions(failures=failures, right_censored=right_censored, a=a)
-    plt.scatter(x, y, marker=".", linewidth=2, c=data_color)
+    if show_scatter_points is True:
+        plt.scatter(x, y, marker=".", linewidth=2, c=data_color)
     plt.gca().set_yscale(
         "function",
         functions=(axes_transforms.gumbel_forward, axes_transforms.gumbel_inverse),
@@ -762,6 +779,7 @@ def Normal_probability_plot(
     CI=0.95,
     CI_type="time",
     show_fitted_distribution=True,
+    show_scatter_points=True,
     **kwargs
 ):
     """
@@ -771,7 +789,8 @@ def Normal_probability_plot(
     Inputs:
     failures - the array or list of failure times
     right_censored - the array or list of right censored failure times
-    show_fitted_distribution - True/False. If true, the fitted distribution will be plotted on the probability plot. Defaults to True
+    show_fitted_distribution - True/False. If True, the fitted distribution will be plotted on the probability plot. Defaults to True
+    show_scatter_points - True/False. If True, the plot will include the scatter points from the failure times. Defaults to True.
     a - the heuristic constant for plotting positions of the form (k-a)/(n+1-2a). Default is a=0.3 which is the median rank method (same as the default in Minitab).
         For more heuristics, see: https://en.wikipedia.org/wiki/Q%E2%80%93Q_plot#Heuristics
     CI - the confidence interval for the bounds. Default is 0.95 for 95% CI.
@@ -847,7 +866,8 @@ def Normal_probability_plot(
 
     # plot the failure points and format the scale and axes
     x, y = plotting_positions(failures=failures, right_censored=right_censored, a=a)
-    plt.scatter(x, y, marker=".", linewidth=2, c=data_color)
+    if show_scatter_points is True:
+        plt.scatter(x, y, marker=".", linewidth=2, c=data_color)
     plt.gca().set_yscale(
         "function",
         functions=(axes_transforms.normal_forward, axes_transforms.normal_inverse),
@@ -878,6 +898,7 @@ def Lognormal_probability_plot(
     CI=0.95,
     CI_type="time",
     show_fitted_distribution=True,
+    show_scatter_points=True,
     **kwargs
 ):
     """
@@ -889,6 +910,7 @@ def Lognormal_probability_plot(
     right_censored - the array or list of right censored failure times
     fit_gamma - True/False. Default is False. Specify this as True in order to fit the Lognormal_3P distribution and scale the x-axis to time - gamma.
     show_fitted_distribution - True/False. If True, the fitted distribution will be plotted on the probability plot. Defaults to True
+    show_scatter_points - True/False. If True, the plot will include the scatter points from the failure times. Defaults to True.
     a - the heuristic constant for plotting positions of the form (k-a)/(n+1-2a). Default is a=0.3 which is the median rank method (same as the default in Minitab).
         For more heuristics, see: https://en.wikipedia.org/wiki/Q%E2%80%93Q_plot#Heuristics
     CI - the confidence interval for the bounds. Default is 0.95 for 95% CI.
@@ -1018,7 +1040,8 @@ def Lognormal_probability_plot(
 
     # plot the failure points and format the scale and axes
     x, y = plotting_positions(failures=failures, right_censored=right_censored, a=a)
-    plt.scatter(x, y, marker=".", linewidth=2, c=data_color)
+    if show_scatter_points is True:
+        plt.scatter(x, y, marker=".", linewidth=2, c=data_color)
     plt.gca().set_yscale(
         "function",
         functions=(axes_transforms.normal_forward, axes_transforms.normal_inverse),
@@ -1048,6 +1071,7 @@ def Beta_probability_plot(
     a=None,
     CI=0.95,
     show_fitted_distribution=True,
+    show_scatter_points=True,
     **kwargs
 ):
     """
@@ -1058,6 +1082,7 @@ def Beta_probability_plot(
     failures - the array or list of failure times
     right_censored - the array or list of right censored failure times
     show_fitted_distribution - True/False. If True, the fitted distribution will be plotted on the probability plot. Defaults to True
+    show_scatter_points - True/False. If True, the plot will include the scatter points from the failure times. Defaults to True.
     a - the heuristic constant for plotting positions of the form (k-a)/(n+1-2a). Default is a=0.3 which is the median rank method (same as the default in Minitab).
         For more heuristics, see: https://en.wikipedia.org/wiki/Q%E2%80%93Q_plot#Heuristics
     kwargs are accepted for the fitted line (eg. linestyle, label, color)
@@ -1119,7 +1144,8 @@ def Beta_probability_plot(
     x, y = plotting_positions(failures=failures, right_censored=right_censored, a=a)
     plt.grid(b=True, which="major", color="k", alpha=0.3, linestyle="-")
     plt.grid(b=True, which="minor", color="k", alpha=0.08, linestyle="-")
-    plt.scatter(x, y, marker=".", linewidth=2, c=data_color)
+    if show_scatter_points is True:
+        plt.scatter(x, y, marker=".", linewidth=2, c=data_color)
     f_beta = lambda x: axes_transforms.beta_forward(x, alpha, beta)
     fi_beta = lambda x: axes_transforms.beta_inverse(x, alpha, beta)
     plt.gca().set_yscale("function", functions=(f_beta, fi_beta))
@@ -1150,6 +1176,7 @@ def Gamma_probability_plot(
     a=None,
     CI=0.95,
     show_fitted_distribution=True,
+    show_scatter_points=True,
     **kwargs
 ):
     """
@@ -1160,7 +1187,8 @@ def Gamma_probability_plot(
     failures - the array or list of failure times
     right_censored - the array or list of right censored failure times
     fit_gamma - True/False. Default is False. Specify this as True in order to fit the Gamma_3P distribution and scale the x-axis to time - gamma.
-    show_fitted_distribution - True/False. If true, the fitted distribution will be plotted on the probability plot. Defaults to True
+    show_fitted_distribution - True/False. If True, the fitted distribution will be plotted on the probability plot. Defaults to True
+    show_scatter_points - True/False. If True, the plot will include the scatter points from the failure times. Defaults to True.
     a - the heuristic constant for plotting positions of the form (k-a)/(n+1-2a). Default is a=0.3 which is the median rank method (same as the default in Minitab).
         For more heuristics, see: https://en.wikipedia.org/wiki/Q%E2%80%93Q_plot#Heuristics
     kwargs are accepted for the fitted line (eg. linestyle, label, color)
@@ -1268,7 +1296,8 @@ def Gamma_probability_plot(
 
     # plot the failure points and format the scale and axes
     x, y = plotting_positions(failures=failures, right_censored=right_censored, a=a)
-    plt.scatter(x, y, marker=".", linewidth=2, c=data_color)
+    if show_scatter_points is True:
+        plt.scatter(x, y, marker=".", linewidth=2, c=data_color)
     f_gamma = lambda x: axes_transforms.gamma_forward(x, beta)
     fi_gamma = lambda x: axes_transforms.gamma_inverse(x, beta)
     plt.gca().set_yscale("function", functions=(f_gamma, fi_gamma))
@@ -1299,6 +1328,7 @@ def Exponential_probability_plot(
     a=None,
     CI=0.95,
     show_fitted_distribution=True,
+    show_scatter_points=True,
     **kwargs
 ):
     """
@@ -1309,7 +1339,8 @@ def Exponential_probability_plot(
     failures - the array or list of failure times
     right_censored - the array or list of right censored failure times
     fit_gamma - True/False. Default is False. Specify this as True in order to fit the Exponential_2P distribution and scale the x-axis to time - gamma.
-    show_fitted_distribution - True/False. If true, the fitted distribution will be plotted on the probability plot. Defaults to True
+    show_fitted_distribution - True/False. If True, the fitted distribution will be plotted on the probability plot. Defaults to True
+    show_scatter_points - True/False. If True, the plot will include the scatter points from the failure times. Defaults to True.
     a - the heuristic constant for plotting positions of the form (k-a)/(n+1-2a). Default is a=0.3 which is the median rank method (same as the default in Minitab).
         For more heuristics, see: https://en.wikipedia.org/wiki/Q%E2%80%93Q_plot#Heuristics
     CI - the confidence interval for the bounds. Default is 0.95 for 95% CI.
@@ -1412,7 +1443,8 @@ def Exponential_probability_plot(
         ef = Exponential_Distribution(Lambda=Lambda, Lambda_SE=Lambda_SE, CI=CI)
 
     x, y = plotting_positions(failures=failures, right_censored=right_censored, a=a)
-    plt.scatter(x, y, marker=".", linewidth=2, c=data_color)
+    if show_scatter_points is True:
+        plt.scatter(x, y, marker=".", linewidth=2, c=data_color)
     plt.gca().set_yscale(
         "function",
         functions=(
